OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Feed de atividade pessoal para %s",
    "Your feed URL is invalid" : "A URL do feed é inválida",
    "Activity feed for %1$s" : "Feed de atividade para %1$s",
    "Activity feed" : "Feed de atividade",
    "Your settings have been updated." : "Suas configurações foram atualizadas.",
    "Settings have been updated." : "As configurações foram atualizadas.",
    "remote user" : "usuário remoto",
    "Recent activity" : "Atividade recente",
    "No activities" : "Sem atividades",
    "More activities" : "Mais atividades",
    "Daily activity summary for %s" : "Resumo de atividade diária para %s",
    "_and %n more…_::_and %n more…_" : ["e mais %n…","e mais %n…","e mais %n…"],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "Você pode desativar os e-mails diários com resumos nas <a href=\"%s\">configurações</a>.",
    "You can disable daily digest emails in the settings: %s" : "Você pode desativar os e-mails diários com resumos nas configurações: %s",
    "All activities" : "Todas as atividades",
    "By others" : "Por outros",
    "By you" : "Por você",
    "Activity at %s" : "Atividade em %s",
    "Hello %s" : "Olá %s",
    "Hello %s," : "Olá %s,",
    "There was some activity at %s" : "Houve alguma atividade em %s",
    "_and %n more _::_and %n more _" : ["e %n mais","e %n mais","e %n mais"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Você pode alterar a frequência destes e-mails ou desativá-los nas <a href=\"%s\">configurações</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Você pode alterar a frequência destes e-mails ou desativá-los nas configurações: %s",
    "Mail" : "E-mail",
    "Push" : "Pressionar",
    "Activity" : "Atividade",
    "Notifications" : "Notificações",
    "This application enables people to view a log of activities about them, their files or other data." : "Esse aplicativo permite que as pessoas visualizem um registro de atividades sobre elas, seus arquivos ou outros dados.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Este aplicativo permite que as pessoas vejam ações relacionadas a seus arquivos e dados no Nextcloud.\n\t\tCada pessoa pode definir suas configurações de atividade individuais nas configurações pessoais,\n\t\tpara escolher qual atividade deve ser enviada para telefones celulares, enviada por e-mail\n\t\tou se um resumo diário é enviado todas as manhãs.\n\t\tMais informações estão disponíveis na documentação da Atividade.",
    "Send email" : "Enviar e-mail",
    "Send push notification" : "Enviar notificação push",
    "Activity notification configuration" : "Configuração de notificações de atividade",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "You need to set up your email address before you can receive notification emails." : "Você precisa configurar o endereço de e-mail para receber mensagens de notificação.",
    "Send activity emails" : "Enviar e-mails de atividades",
    "As soon as possible" : "Assim que possível",
    "Hourly" : "De hora em hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Você comentou",
    "Message deleted by author" : "Mensagem excluída pelo autor",
    "Open {filename}" : "Abrir {filename}",
    "in {path}" : "em {path}",
    "Home" : "Início",
    "Could not load activities" : "Não foi possível carregar atividades",
    "Loading activities" : "Carregando atividades",
    "This stream will show events like additions, changes & shares" : "Este stream vai exibir eventos como aditamentos, alterações e compartilhamentos",
    "No activity yet" : "Nenhuma atividade",
    "Loading more activities" : "Carregando mais atividades",
    "No more activities." : "Não há mais atividades.",
    "Could not enable RSS link" : "Não foi possível ativar link RSS",
    "RSS link copied to clipboard" : "Link RSS copiado para área de transferência",
    "Could not copy the RSS link, please copy manually:" : "Não foi possível copiar o link RSS, por favor copie manualmente:",
    "Activity settings" : "Configurações de atividade",
    "Enable RSS feed" : "Ativar feed RSS",
    "RSS feed" : "Feed RSS",
    "Copy RSS feed link" : "Copiar o link do feed RSS",
    "Personal notification settings" : "Configurações de notificação pessoais",
    "Unable to load the activity list" : "Não foi possível carregar a lista de atividades",
    "Choose for which activities you want to get an email or push notification." : "Escolha para quais atividades você gostaria de receber um e-mail ou uma notificação por push.",
    "Choose for which activities you want to get a push notification." : "Escolha para quais atividades você gostaria de receber uma notificação por push.",
    "Notification" : "Notificação",
    "Enable notification emails" : "Ativar e-mails de notificação",
    "Daily activity summary" : "Resumo diário de atividades",
    "Send daily activity summary in the morning" : "Enviar o resumo da atividade diária pela manhã",
    "Default settings" : "Configurações padrões",
    "Configure the default notification settings for new accounts." : "Configuras as definições de notificação padrão para novas contas.",
    "Unable to save the settings" : "Não foi possível salvar as configurações",
    "No more events to load" : "Não há mais eventos para carregar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
